@@ -83,13 +83,24 @@ def login(request):
     return HttpResponseRedirect(redirect_to=app_redirect_url)
 
 
+def _get_public_identity_host(request):
+    """
+    Doing it in a super dumb way for now, lets see if we need smth more complex later
+    :return:
+    """
+    host = request.get_host()
+    domain_name = host.split('//')[-1]
+    parent_domain = '.'.join(domain_name.split('.')[1:])
+    return 'https://id.' + parent_domain
+
+
 @api_view(["GET"])
 @permission_classes([AllowAny])
 @authentication_classes([])
 def logout(request):
     request.session.flush()
     state: str = request.query_params.get("state", "")
-    redirect_url = urljoin(settings.IDENTITY_HOST, "auth/logout/")
+    redirect_url = urljoin(_get_public_identity_host(request), "auth/logout/")
     response = HttpResponseRedirect(redirect_to=f"{redirect_url}?state={state}")
     return response
 
